Devices API
===========

The Devices API is contained in one module, :mod:`lewis.devices`, described below.

The Devices Module
------------------

.. automodule:: lewis.devices
    :members: Device

.. autoclass:: lewis.devices.StateMachineDevice
    :members: _get_state_handlers, _get_initial_state, _get_transition_handlers, _initialize_data
